Module Name:    src
Committed By:   andvar
Date:           Sun Dec 26 16:08:21 UTC 2021

Modified Files:
        src/share/man/man4/man4.amiga: xsh.4
        src/sys/arch/amiga/dev: grf_cl.c grf_cv.c grf_cv3d.c grf_et.c
        src/sys/arch/arm/iomd: vidcvideo.c
        src/sys/arch/arm/xscale: pxa2x0reg.h
        src/sys/arch/evbmips/conf: CPMBR1400 LINKITSMART7688 ZYXELKX
        src/sys/arch/ews4800mips/conf: GENERIC
        src/sys/arch/hpcarm/conf: NETBOOKPRO
        src/sys/arch/i386/include: frame.h
        src/sys/arch/luna68k/conf: files.luna68k
        src/sys/arch/macppc/conf: POWERMAC_G5
        src/sys/arch/pmax/ibus: siivar.h
        src/sys/dev/pci: cmdide.c pciidevar.h
        src/sys/dev/usb: ukbd.c

Log Message:
fix various typos, mainly in comments.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/share/man/man4/man4.amiga/xsh.4
cvs rdiff -u -r1.53 -r1.54 src/sys/arch/amiga/dev/grf_cl.c
cvs rdiff -u -r1.61 -r1.62 src/sys/arch/amiga/dev/grf_cv.c
cvs rdiff -u -r1.36 -r1.37 src/sys/arch/amiga/dev/grf_cv3d.c
cvs rdiff -u -r1.38 -r1.39 src/sys/arch/amiga/dev/grf_et.c
cvs rdiff -u -r1.48 -r1.49 src/sys/arch/arm/iomd/vidcvideo.c
cvs rdiff -u -r1.25 -r1.26 src/sys/arch/arm/xscale/pxa2x0reg.h
cvs rdiff -u -r1.34 -r1.35 src/sys/arch/evbmips/conf/CPMBR1400
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/evbmips/conf/LINKITSMART7688
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/evbmips/conf/ZYXELKX
cvs rdiff -u -r1.63 -r1.64 src/sys/arch/ews4800mips/conf/GENERIC
cvs rdiff -u -r1.32 -r1.33 src/sys/arch/hpcarm/conf/NETBOOKPRO
cvs rdiff -u -r1.40 -r1.41 src/sys/arch/i386/include/frame.h
cvs rdiff -u -r1.28 -r1.29 src/sys/arch/luna68k/conf/files.luna68k
cvs rdiff -u -r1.49 -r1.50 src/sys/arch/macppc/conf/POWERMAC_G5
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/pmax/ibus/siivar.h
cvs rdiff -u -r1.46 -r1.47 src/sys/dev/pci/cmdide.c
cvs rdiff -u -r1.50 -r1.51 src/sys/dev/pci/pciidevar.h
cvs rdiff -u -r1.154 -r1.155 src/sys/dev/usb/ukbd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/man4.amiga/xsh.4
diff -u src/share/man/man4/man4.amiga/xsh.4:1.10 src/share/man/man4/man4.amiga/xsh.4:1.11
--- src/share/man/man4/man4.amiga/xsh.4:1.10	Sat Feb 18 22:39:00 2017
+++ src/share/man/man4/man4.amiga/xsh.4	Sun Dec 26 16:08:19 2021
@@ -1,4 +1,4 @@
-.\" $NetBSD: xsh.4,v 1.10 2017/02/18 22:39:00 wiz Exp $
+.\" $NetBSD: xsh.4,v 1.11 2021/12/26 16:08:19 andvar Exp $
 .\"
 .\" Copyright (c) 2013 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -42,7 +42,7 @@ The
 .Nm
 driver provides support for ethernet interface present on the Individual
 Computers X-Surf 100 card.
-It acts as a bus attachment layer for the machine idependent
+It acts as a bus attachment layer for the machine independent
 .Xr ne 4
 driver, which supports the AX88796 chip.
 .Sh HARDWARE

Index: src/sys/arch/amiga/dev/grf_cl.c
diff -u src/sys/arch/amiga/dev/grf_cl.c:1.53 src/sys/arch/amiga/dev/grf_cl.c:1.54
--- src/sys/arch/amiga/dev/grf_cl.c:1.53	Mon Oct  4 20:48:05 2021
+++ src/sys/arch/amiga/dev/grf_cl.c	Sun Dec 26 16:08:19 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: grf_cl.c,v 1.53 2021/10/04 20:48:05 andvar Exp $ */
+/*	$NetBSD: grf_cl.c,v 1.54 2021/12/26 16:08:19 andvar Exp $ */
 
 /*
  * Copyright (c) 1997 Klaus Burkert
@@ -36,7 +36,7 @@
 #include "opt_amigacons.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_cl.c,v 1.53 2021/10/04 20:48:05 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_cl.c,v 1.54 2021/12/26 16:08:19 andvar Exp $");
 
 #include "grfcl.h"
 #include "ite.h"
@@ -2124,7 +2124,7 @@ cl_wsioctl(void *v, void *vs, u_long cmd
 		return cl_get_fbinfo(gp, data);
 	}
 
-	/* handle this command hw-independant in grf(4) */
+	/* handle this command hw-independent in grf(4) */
 	return grf_wsioctl(v, vs, cmd, data, flag, l);
 }
 

Index: src/sys/arch/amiga/dev/grf_cv.c
diff -u src/sys/arch/amiga/dev/grf_cv.c:1.61 src/sys/arch/amiga/dev/grf_cv.c:1.62
--- src/sys/arch/amiga/dev/grf_cv.c:1.61	Sat Aug  7 16:18:41 2021
+++ src/sys/arch/amiga/dev/grf_cv.c	Sun Dec 26 16:08:19 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: grf_cv.c,v 1.61 2021/08/07 16:18:41 thorpej Exp $ */
+/*	$NetBSD: grf_cv.c,v 1.62 2021/12/26 16:08:19 andvar Exp $ */
 
 /*
  * Copyright (c) 1995 Michael Teske
@@ -33,7 +33,7 @@
 #include "opt_amigacons.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_cv.c,v 1.61 2021/08/07 16:18:41 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_cv.c,v 1.62 2021/12/26 16:08:19 andvar Exp $");
 
 #include "grfcv.h"
 #include "ite.h"
@@ -2511,7 +2511,7 @@ cv_wsioctl(void *v, void *vs, u_long cmd
 		return cv_get_fbinfo(gp, data);
 	}
 
-	/* handle this command hw-independant in grf(4) */
+	/* handle this command hw-independent in grf(4) */
 	return grf_wsioctl(v, vs, cmd, data, flag, l);
 }
 

Index: src/sys/arch/amiga/dev/grf_cv3d.c
diff -u src/sys/arch/amiga/dev/grf_cv3d.c:1.36 src/sys/arch/amiga/dev/grf_cv3d.c:1.37
--- src/sys/arch/amiga/dev/grf_cv3d.c:1.36	Sat Aug  7 16:18:41 2021
+++ src/sys/arch/amiga/dev/grf_cv3d.c	Sun Dec 26 16:08:19 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: grf_cv3d.c,v 1.36 2021/08/07 16:18:41 thorpej Exp $ */
+/*	$NetBSD: grf_cv3d.c,v 1.37 2021/12/26 16:08:19 andvar Exp $ */
 
 /*
  * Copyright (c) 1995 Michael Teske
@@ -33,7 +33,7 @@
 #include "opt_amigacons.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_cv3d.c,v 1.36 2021/08/07 16:18:41 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_cv3d.c,v 1.37 2021/12/26 16:08:19 andvar Exp $");
 
 #include "grfcv3d.h"
 #include "ite.h"
@@ -2365,7 +2365,7 @@ cv3d_wsioctl(void *v, void *vs, u_long c
 		return cv3d_get_fbinfo(gp, data);
 	}
 
-	/* handle this command hw-independant in grf(4) */
+	/* handle this command hw-independent in grf(4) */
 	return grf_wsioctl(v, vs, cmd, data, flag, l);
 }
 

Index: src/sys/arch/amiga/dev/grf_et.c
diff -u src/sys/arch/amiga/dev/grf_et.c:1.38 src/sys/arch/amiga/dev/grf_et.c:1.39
--- src/sys/arch/amiga/dev/grf_et.c:1.38	Sat Aug  7 16:18:41 2021
+++ src/sys/arch/amiga/dev/grf_et.c	Sun Dec 26 16:08:19 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: grf_et.c,v 1.38 2021/08/07 16:18:41 thorpej Exp $ */
+/*	$NetBSD: grf_et.c,v 1.39 2021/12/26 16:08:19 andvar Exp $ */
 
 /*
  * Copyright (c) 1997 Klaus Burkert
@@ -37,7 +37,7 @@
 #include "opt_amigacons.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_et.c,v 1.38 2021/08/07 16:18:41 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_et.c,v 1.39 2021/12/26 16:08:19 andvar Exp $");
 
 #include "grfet.h"
 #include "ite.h"
@@ -1954,7 +1954,7 @@ et_wsioctl(void *v, void *vs, u_long cmd
 		return et_get_fbinfo(gp, data);
 	}
 
-	/* handle this command hw-independant in grf(4) */
+	/* handle this command hw-independent in grf(4) */
 	return grf_wsioctl(v, vs, cmd, data, flag, l);
 }
 

Index: src/sys/arch/arm/iomd/vidcvideo.c
diff -u src/sys/arch/arm/iomd/vidcvideo.c:1.48 src/sys/arch/arm/iomd/vidcvideo.c:1.49
--- src/sys/arch/arm/iomd/vidcvideo.c:1.48	Fri Aug 20 20:25:27 2021
+++ src/sys/arch/arm/iomd/vidcvideo.c	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: vidcvideo.c,v 1.48 2021/08/20 20:25:27 andvar Exp $ */
+/* $NetBSD: vidcvideo.c,v 1.49 2021/12/26 16:08:20 andvar Exp $ */
 
 /*
  * Copyright (c) 2001 Reinoud Zandijk
@@ -30,7 +30,7 @@
 
 #include <sys/cdefs.h>			/* RCS ID & Copyright macro defns */
 
-__KERNEL_RCSID(0, "$NetBSD: vidcvideo.c,v 1.48 2021/08/20 20:25:27 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vidcvideo.c,v 1.49 2021/12/26 16:08:20 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -56,7 +56,7 @@ __KERNEL_RCSID(0, "$NetBSD: vidcvideo.c,
 #include <arm/arm32/pmap.h>
 #include <arm/cpufunc.h>
 
-/* for vidc_mode ... needs to be MI indepenent one day */
+/* for vidc_mode ... needs to be MI independent one day */
 #include <arm/iomd/vidc.h>
 #include <arm/iomd/vidc20config.h>
 #include <arm/iomd/vidcvideo.h>

Index: src/sys/arch/arm/xscale/pxa2x0reg.h
diff -u src/sys/arch/arm/xscale/pxa2x0reg.h:1.25 src/sys/arch/arm/xscale/pxa2x0reg.h:1.26
--- src/sys/arch/arm/xscale/pxa2x0reg.h:1.25	Sun Dec  5 07:56:10 2021
+++ src/sys/arch/arm/xscale/pxa2x0reg.h	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: pxa2x0reg.h,v 1.25 2021/12/05 07:56:10 msaitoh Exp $ */
+/* $NetBSD: pxa2x0reg.h,v 1.26 2021/12/26 16:08:20 andvar Exp $ */
 
 /*
  * Copyright (c) 2002  Genetec Corporation.  All rights reserved.
@@ -94,7 +94,7 @@
 #define PXA2X0_I2S_SIZE		0x84
 #define PXA2X0_AC97_BASE	0x40500000 /* AC '97 Controller */
 #define PXA2X0_AC97_SIZE	0x600
-#define PXA2X0_USBDC_BASE 	0x40600000 /* USB Client Contoller */
+#define PXA2X0_USBDC_BASE 	0x40600000 /* USB Client Controller */
 #define PXA250_USBDC_SIZE 	0xe04
 #define PXA270_USBDC_SIZE 	0x460
 #define PXA2X0_STUART_BASE	0x40700000 /* Standard UART */

Index: src/sys/arch/evbmips/conf/CPMBR1400
diff -u src/sys/arch/evbmips/conf/CPMBR1400:1.34 src/sys/arch/evbmips/conf/CPMBR1400:1.35
--- src/sys/arch/evbmips/conf/CPMBR1400:1.34	Thu Jan 21 06:51:54 2021
+++ src/sys/arch/evbmips/conf/CPMBR1400	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: CPMBR1400,v 1.34 2021/01/21 06:51:54 nia Exp $
+#	$NetBSD: CPMBR1400,v 1.35 2021/12/26 16:08:20 andvar Exp $
 
 include 	"arch/evbmips/conf/std.rasoc"
 
@@ -85,7 +85,7 @@ file-system	TMPFS		# Efficient memory fi
 # File system options
 #options 	QUOTA		# UFS quotas
 #options 	DISKLABEL_EI	# disklabel Endian Independent support
-#options 	FFS_EI		# FFS Endian Independant support
+#options 	FFS_EI		# FFS Endian Independent support
 #options 	NFSSERVER	# Network File System server
 options 	FFS_NO_SNAPSHOT	# No FF snapshot support
 #options 	EXT2FS_SYSTEM_FLAGS # makes ext2fs file flags (append and immutable) behave as system flags.

Index: src/sys/arch/evbmips/conf/LINKITSMART7688
diff -u src/sys/arch/evbmips/conf/LINKITSMART7688:1.16 src/sys/arch/evbmips/conf/LINKITSMART7688:1.17
--- src/sys/arch/evbmips/conf/LINKITSMART7688:1.16	Thu Jan 21 06:51:54 2021
+++ src/sys/arch/evbmips/conf/LINKITSMART7688	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: LINKITSMART7688,v 1.16 2021/01/21 06:51:54 nia Exp $
+#	$NetBSD: LINKITSMART7688,v 1.17 2021/12/26 16:08:20 andvar Exp $
 #
 # MediaTek MT7688
 #
@@ -88,7 +88,7 @@ file-system	TMPFS		# Efficient memory fi
 # File system options
 #options 	QUOTA		# UFS quotas
 #options 	DISKLABEL_EI	# disklabel Endian Independent support
-#options 	FFS_EI		# FFS Endian Independant support
+#options 	FFS_EI		# FFS Endian Independent support
 #options 	NFSSERVER	# Network File System server
 options 	FFS_NO_SNAPSHOT	# No FF snapshot support
 #options 	EXT2FS_SYSTEM_FLAGS # makes ext2fs file flags (append and immutable) behave as system flags.

Index: src/sys/arch/evbmips/conf/ZYXELKX
diff -u src/sys/arch/evbmips/conf/ZYXELKX:1.19 src/sys/arch/evbmips/conf/ZYXELKX:1.20
--- src/sys/arch/evbmips/conf/ZYXELKX:1.19	Thu Jan 21 06:51:54 2021
+++ src/sys/arch/evbmips/conf/ZYXELKX	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: ZYXELKX,v 1.19 2021/01/21 06:51:54 nia Exp $
+#	$NetBSD: ZYXELKX,v 1.20 2021/12/26 16:08:20 andvar Exp $
 
 include 	"arch/evbmips/conf/std.rasoc"
 
@@ -85,7 +85,7 @@ file-system	TMPFS		# Efficient memory fi
 # File system options
 #options 	QUOTA		# UFS quotas
 #options 	DISKLABEL_EI	# disklabel Endian Independent support
-#options 	FFS_EI		# FFS Endian Independant support
+#options 	FFS_EI		# FFS Endian Independent support
 #options 	NFSSERVER	# Network File System server
 options 	FFS_NO_SNAPSHOT	# No FF snapshot support
 #options 	EXT2FS_SYSTEM_FLAGS # makes ext2fs file flags (append and immutable) behave as system flags.

Index: src/sys/arch/ews4800mips/conf/GENERIC
diff -u src/sys/arch/ews4800mips/conf/GENERIC:1.63 src/sys/arch/ews4800mips/conf/GENERIC:1.64
--- src/sys/arch/ews4800mips/conf/GENERIC:1.63	Thu Jan 21 06:51:54 2021
+++ src/sys/arch/ews4800mips/conf/GENERIC	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.63 2021/01/21 06:51:54 nia Exp $
+# $NetBSD: GENERIC,v 1.64 2021/12/26 16:08:20 andvar Exp $
 #
 # GENERIC machine description file
 # This machine description file is used to generate the default NetBSD
@@ -25,7 +25,7 @@ include 	"arch/ews4800mips/conf/std.ews4
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident		"GENERIC-$Revision: 1.63 $"
+#ident		"GENERIC-$Revision: 1.64 $"
 
 maxusers	16
 
@@ -100,7 +100,7 @@ file-system	TMPFS		# Efficient memory fi
 # File system options
 options 	QUOTA		# legacy UFS quotas
 options 	QUOTA2		# new, in-filesystem UFS quotas
-#options 	FFS_EI		# FFS Endian Indpendent support
+#options 	FFS_EI		# FFS Endian Independent support
 options 	WAPBL		# File system journaling support
 #options 	UFS_DIRHASH	# UFS Large Directory Hashing - Experimental
 options 	NFSSERVER	# Network File System server

Index: src/sys/arch/hpcarm/conf/NETBOOKPRO
diff -u src/sys/arch/hpcarm/conf/NETBOOKPRO:1.32 src/sys/arch/hpcarm/conf/NETBOOKPRO:1.33
--- src/sys/arch/hpcarm/conf/NETBOOKPRO:1.32	Sat Apr 18 11:00:41 2020
+++ src/sys/arch/hpcarm/conf/NETBOOKPRO	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: NETBOOKPRO,v 1.32 2020/04/18 11:00:41 skrll Exp $
+#	$NetBSD: NETBOOKPRO,v 1.33 2021/12/26 16:08:20 andvar Exp $
 #
 #	NETBOOKPRO -- Psion Teklogix NETBOOK PRO
 #
@@ -8,7 +8,7 @@ include	"arch/hpcarm/conf/files.netbookp
 
 #options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		"GENERIC-$Revision: 1.32 $"
+#ident 		"GENERIC-$Revision: 1.33 $"
 
 # estimated number of users
 maxusers	32
@@ -58,7 +58,7 @@ file-system	TMPFS		# Efficient memory fi
 # File system options
 #options 	QUOTA		# legacy UFS quotas
 #options 	QUOTA2		# new, in-filesystem UFS quotas
-options 	FFS_EI		# FFS Endian Independant support
+options 	FFS_EI		# FFS Endian Independent support
 #options 	WAPBL		# File system journaling support
 #options 	FFS_NO_SNAPSHOT	# No FFS snapshot support
 #options 	NFSSERVER

Index: src/sys/arch/i386/include/frame.h
diff -u src/sys/arch/i386/include/frame.h:1.40 src/sys/arch/i386/include/frame.h:1.41
--- src/sys/arch/i386/include/frame.h:1.40	Thu Feb 14 08:18:25 2019
+++ src/sys/arch/i386/include/frame.h	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: frame.h,v 1.40 2019/02/14 08:18:25 cherry Exp $	*/
+/*	$NetBSD: frame.h,v 1.41 2021/12/26 16:08:20 andvar Exp $	*/
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -131,7 +131,7 @@ struct intrframe {
 
 #ifdef XEN
 /*
- * need arch independant way to access ip and cs from intrframe
+ * need arch independent way to access ip and cs from intrframe
  */
 #define	_INTRFRAME_CS	if_cs
 #define	_INTRFRAME_IP	if_eip

Index: src/sys/arch/luna68k/conf/files.luna68k
diff -u src/sys/arch/luna68k/conf/files.luna68k:1.28 src/sys/arch/luna68k/conf/files.luna68k:1.29
--- src/sys/arch/luna68k/conf/files.luna68k:1.28	Mon Feb 18 01:12:23 2019
+++ src/sys/arch/luna68k/conf/files.luna68k	Sun Dec 26 16:08:20 2021
@@ -1,5 +1,5 @@
 #
-#	$NetBSD: files.luna68k,v 1.28 2019/02/18 01:12:23 thorpej Exp $
+#	$NetBSD: files.luna68k,v 1.29 2021/12/26 16:08:20 andvar Exp $
 #
 maxpartitions 8
 maxusers 2 8 64
@@ -65,7 +65,7 @@ file arch/luna68k/dev/omrasops.c	fb
 attach spc at mainbus
 file arch/luna68k/dev/spc.c		spc
 
-# Machine-idependent SCSI driver.
+# Machine-independent SCSI driver.
 include "dev/scsipi/files.scsipi"
 
 # Memory Disk for boot tape

Index: src/sys/arch/macppc/conf/POWERMAC_G5
diff -u src/sys/arch/macppc/conf/POWERMAC_G5:1.49 src/sys/arch/macppc/conf/POWERMAC_G5:1.50
--- src/sys/arch/macppc/conf/POWERMAC_G5:1.49	Fri Apr  2 09:27:32 2021
+++ src/sys/arch/macppc/conf/POWERMAC_G5	Sun Dec 26 16:08:20 2021
@@ -79,7 +79,7 @@ file-system	PTYFS		# /dev/pts/N support
 # File system options
 options 	QUOTA		# legacy UFS quotas
 options 	QUOTA2		# new, in-filesystem UFS quotas
-#options 	FFS_EI		# FFS Endian Independant support
+#options 	FFS_EI		# FFS Endian Independent support
 options 	WAPBL		# File system journaling support
 #options 	UFS_DIRHASH	# UFS Large Directory Hashing - Experimental
 #options 	NFSSERVER	# Network File System server

Index: src/sys/arch/pmax/ibus/siivar.h
diff -u src/sys/arch/pmax/ibus/siivar.h:1.4 src/sys/arch/pmax/ibus/siivar.h:1.5
--- src/sys/arch/pmax/ibus/siivar.h:1.4	Sat Jun  4 01:31:23 2011
+++ src/sys/arch/pmax/ibus/siivar.h	Sun Dec 26 16:08:20 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: siivar.h,v 1.4 2011/06/04 01:31:23 tsutsui Exp $	*/
+/*	$NetBSD: siivar.h,v 1.5 2021/12/26 16:08:20 andvar Exp $	*/
 
 #ifndef _SIIVAR_H
 #define _SIIVAR_H
@@ -65,7 +65,7 @@ struct siisoftc {
 
 int	siiintr(void *sc);
 
-/* Machine-indepedent back-end attach entry point */
+/* Machine-independent back-end attach entry point */
 
 void	sii_scsi_request(struct scsipi_channel *,
 				scsipi_adapter_req_t, void *);

Index: src/sys/dev/pci/pciidevar.h
diff -u src/sys/dev/pci/pciidevar.h:1.50 src/sys/dev/pci/pciidevar.h:1.51
--- src/sys/dev/pci/pciidevar.h:1.50	Thu Apr 19 21:50:09 2018
+++ src/sys/dev/pci/pciidevar.h	Sun Dec 26 16:08:21 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: pciidevar.h,v 1.50 2018/04/19 21:50:09 christos Exp $	*/
+/*	$NetBSD: pciidevar.h,v 1.51 2021/12/26 16:08:21 andvar Exp $	*/
 
 /*
  * Copyright (c) 1998 Christopher G. Demetriou.  All rights reserved.
@@ -179,7 +179,7 @@ struct pciide_product_desc {
 
 /* Flags for ide_flags */
 #define	IDE_16BIT_IOSPACE	0x0002 /* I/O space BARS ignore upper word */
-#define	IDE_SHARED_CHANNELS	0x0004 /* channels are not independant */
+#define	IDE_SHARED_CHANNELS	0x0004 /* channels are not independent */
 
 
 /* inlines for reading/writing 8-bit PCI registers */

Index: src/sys/dev/usb/ukbd.c
diff -u src/sys/dev/usb/ukbd.c:1.154 src/sys/dev/usb/ukbd.c:1.155
--- src/sys/dev/usb/ukbd.c:1.154	Sat Dec 25 13:41:12 2021
+++ src/sys/dev/usb/ukbd.c	Sun Dec 26 16:08:21 2021
@@ -1,4 +1,4 @@
-/*      $NetBSD: ukbd.c,v 1.154 2021/12/25 13:41:12 riastradh Exp $        */
+/*      $NetBSD: ukbd.c,v 1.155 2021/12/26 16:08:21 andvar Exp $        */
 
 /*
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ukbd.c,v 1.154 2021/12/25 13:41:12 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ukbd.c,v 1.155 2021/12/26 16:08:21 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_ddb.h"
@@ -1024,7 +1024,7 @@ ukbd_cnattach(void)
 	/*
 	 * XXX USB requires too many parts of the kernel to be running
 	 * XXX in order to work, so we can't do much for the console
-	 * XXX keyboard until autconfiguration has run its course.
+	 * XXX keyboard until autoconfiguration has run its course.
 	 */
 	ukbd_is_console = 1;
 	return 0;

Reply via email to
Index: src/sys/dev/pci/cmdide.c
diff -u src/sys/dev/pci/cmdide.c:1.46 src/sys/dev/pci/cmdide.c:1.47
--- src/sys/dev/pci/cmdide.c:1.46	Fri Jul 17 21:04:14 2020
+++ src/sys/dev/pci/cmdide.c	Sun Dec 26 16:08:21 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: cmdide.c,v 1.46 2020/07/17 21:04:14 jdolecek Exp $	*/
+/*	$NetBSD: cmdide.c,v 1.47 2021/12/26 16:08:21 andvar Exp $	*/
 
 /*
  * Copyright (c) 1999, 2000, 2001 Manuel Bouyer.
@@ -25,7 +25,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cmdide.c,v 1.46 2020/07/17 21:04:14 jdolecek Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cmdide.c,v 1.47 2021/12/26 16:08:21 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -155,7 +155,7 @@ cmd_channel_map(const struct pci_attach_
 	cp->ata_channel.ch_atac = &sc->sc_wdcdev.sc_atac;
 
 	if (channel > 0 && one_channel) {
 		/* Channels are not independant, need synchronization */
 		sc->sc_wdcdev.sc_atac.atac_claim_hw = cmd064x_claim_hw;
 		sc->sc_wdcdev.sc_atac.atac_free_hw  = cmd064x_free_hw;
 		sc->sc_cmd_act_channel = CMDIDE_ACT_CHANNEL_NONE;
@@ -167,7 +167,7 @@ cmd_channel_map(const struct pci_attach_
 	    "configured" : "wired",
 	    (interface & PCIIDE_INTERFACE_PCI(channel)) ?
 	    "native-PCI" : "compatibility",
-	    one_channel ? ", channel non-independant" : "");
+	    one_channel ? ", channel non-independent" : "");
 
 	/*
 	 * with a CMD PCI64x, if we get here, the first channel is enabled:
@@ -155,7 +155,7 @@ cmd_channel_map(const struct pci_attach_
 
 	if (channel > 0 && one_channel) {
-		/* Channels are not independant, need synchronization */
+		/* Channels are not independent, need synchronization */
 		sc->sc_wdcdev.sc_atac.atac_claim_hw = cmd064x_claim_hw;
 		sc->sc_wdcdev.sc_atac.atac_free_hw  = cmd064x_free_hw;
